/**
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.osgi.service.jdbc;

import java.util.Properties;

import javax.sql.DataSource;

/**
 * DataSource providers should implement this interface and register it as an
 * OSGi service with the JDBC driver class name in the "osg.jdbc.driver" property.
 *
 * COPY FROM THE OSGi R4.2.
 */
public interface DataSourceFactory {

    /**
     * Mandatory service property specifying the type of the database.
     */
    public static final String JDBC_DRIVER = "osgi.jdbc.driver";

    /**
     * Key for the DataSource configuration.
     */
    public static final String JDBC_URL = "org.jdbc.url";

    /**
     * Key for the DataSource configuration.
     */
    public static final String JDBC_USER = "org.jdbc.user";

    /**
     * Key for the DataSource configuration.
     */
    public static final String JDBC_PASSWORD = "org.jdbc.password";


    /**
     * Gets a data source object matching the given configuration.
     * @param props the configuration. This configuration may contain
     * others properties as the specified ones.
     * @return a data source object matching the given configuration.
     * <code>null</code> if the configuration is not suitable.
     */
    public DataSource createDataSource( Properties props);
}
